==> beagle-0.0.11.1.tar.bz2: beagle-0.0.11.1/Tiles/TranslationHack.cs <==
using Mono.Posix;

public class TranslationHack {
	private void NotToBecalled () {
		/* For translators: From template Tiles/template-docs.html */
		Catalog.GetString ("in folder");
		/* For translators: From template Tiles/template-docs.html */
		Catalog.GetString ("Last modified");
		/* For translators: From template Tiles/template-docs.html */
		Catalog.GetString ("Title:");
		/* For translators: From template Tiles/template-docs.html */
		Catalog.GetString ("Author:");
		/* For translators: From template Tiles/template-docs.html */
		Catalog.GetString ("Open");
		/* For translators: From template Tiles/template-docs.html */
		Catalog.GetString ("Send to...");
		/* For translators: From template Tiles/template-docs.html */
		Catalog.GetString ("Reveal in file manager");
		/* For translators: From template Tiles/template-launcher.html */
		Catalog.GetString ("Application:");
		/* For translators: From template Tiles/template-launcher.html */
		Catalog.GetString ("Open");
		/* For translators: From template Tiles/template-folder.html */
		Catalog.GetString ("in folder");
		/* For translators: From template Tiles/template-folder.html */
		Catalog.GetString ("Open");
		/* For translators: From template Tiles/template-file.html */
		Catalog.GetString ("in folder");
		/* For translators: From template Tiles/template-file.html */
		Catalog.GetString ("Last modified");
		/* For translators: From template Tiles/template-file.html */
		Catalog.GetString ("Open");
		/* For translators: From template Tiles/template-file.html */
		Catalog.GetString ("Send to...");
		/* For translators: From template Tiles/template-file.html */
		Catalog.GetString ("Reveal in file manager");
		/* For translators: From template Tiles/template-im-log.html */
		Catalog.GetString ("Open");
		/* For translators: From template Tiles/template-mail-message.html */
		Catalog.GetString ("Folder:");
		/* For translators: From template Tiles/template-mail-message.html */
		Catalog.GetString ("Open");
		/* For translators: From template Tiles/template-mail-message.html */
		Catalog.GetString ("Send IM");
		/* For translators: From template Tiles/template-music.html */
		Catalog.GetString ("Track");
		/* For translators: From template Tiles/template-music.html */
		Catalog.GetString ("from");
		/* For translators: From template Tiles/template-music.html */
		Catalog.GetString ("Open");
		/* For translators: From template Tiles/template-music.html */
		Catalog.GetString ("Enqueue");
		/* For translators: From template Tiles/template-music.html */
		Catalog.GetString ("Reveal in file manager");
		/* For translators: From template Tiles/template-note.html */
		Catalog.GetString ("last modified");
		/* For translators: From template Tiles/template-note.html */
		Catalog.GetString ("Open");
		/* For translators: From template Tiles/template-picture.html */
		Catalog.GetString ("in folder");
		/* For translators: From template Tiles/template-picture.html */
		Catalog.GetString ("Modified:");
		/* For translators: From template Tiles/template-picture.html */
		Catalog.GetString ("Open");
		/* For translators: From template Tiles/template-picture.html */
		Catalog.GetString ("Send to...");
		/* For translators: From template Tiles/template-picture.html */
		Catalog.GetString ("Reveal in file manager");
		/* For translators: From template Tiles/template-presentation.html */
		Catalog.GetString ("in folder");
		/* For translators: From template Tiles/template-presentation.html */
		Catalog.GetString ("Last modified");
		/* For translators: From template Tiles/template-presentation.html */
		Catalog.GetString ("Title:");
		/* For translators: From template Tiles/template-presentation.html */
		Catalog.GetString ("Author:");
		/* For translators: From template Tiles/template-presentation.html */
		Catalog.GetString ("Slides:");
		/* For translators: From template Tiles/template-presentation.html */
		Catalog.GetString ("Open");
		/* For translators: From template Tiles/template-presentation.html */
		Catalog.GetString ("Send to...");
		/* For translators: From template Tiles/template-presentation.html */
		Catalog.GetString ("Reveal in file manager");
		/* For translators: From template Tiles/template-web-history.html */
		Catalog.GetString ("Last viewed:");
		/* For translators: From template Tiles/template-web-history.html */
		Catalog.GetString ("Open");
		/* For translators: From template Tiles/template-blog.html */
		Catalog.GetString ("Weblog:");
		/* For translators: From template Tiles/template-blog.html */
		Catalog.GetString ("Published:");
		/* For translators: From template Tiles/template-blog.html */
		Catalog.GetString ("Open");
	}
}

==> beagle-0.1.3.tar.bz2: beagle-0.1.3/Tiles/TranslationHack.cs <==
using Mono.Unix;

public class TranslationHack {
	private void NotToBecalled () {
		/* For translators: From template Tiles/template-blog.html */
		Catalog.GetString ("Weblog:");
		/* For translators: From template Tiles/template-blog.html */
		Catalog.GetString ("by");
		/* For translators: From template Tiles/template-blog.html */
		Catalog.GetString ("Published:");
		/* For translators: From template Tiles/template-blog.html */
		Catalog.GetString ("Open");
		/* For translators: From template Tiles/template-docs.html */
		Catalog.GetString ("in folder");
		/* For translators: From template Tiles/template-docs.html */
		Catalog.GetString ("Last modified");
		/* For translators: From template Tiles/template-docs.html */
		Catalog.GetString ("Title:");
		/* For translators: From template Tiles/template-docs.html */
		Catalog.GetString ("Author:");
		/* For translators: From template Tiles/template-docs.html */
		Catalog.GetString ("Open");
		/* For translators: From template Tiles/template-docs.html */
		Catalog.GetString ("Send to...");
		/* For translators: From template Tiles/template-docs.html */
		Catalog.GetString ("Reveal in file manager");
		/* For translators: From template Tiles/template-file.html */
		Catalog.GetString ("in folder");
		/* For translators: From template Tiles/template-file.html */
		Catalog.GetString ("Last modified");
		/* For translators: From template Tiles/template-file.html */
		Catalog.GetString ("Open");
		/* For translators: From template Tiles/template-file.html */
		Catalog.GetString ("Send to...");
		/* For translators: From template Tiles/template-file.html */
		Catalog.GetString ("Reveal in file manager");
		/* For translators: From template Tiles/template-folder.html */
		Catalog.GetString ("in folder");
		/* For translators: From template Tiles/template-folder.html */
		Catalog.GetString ("Open");
		/* For translators: From template Tiles/template-launcher.html */
		Catalog.GetString ("Application:");
		/* For translators: From template Tiles/template-launcher.html */
		Catalog.GetString ("Open");
		/* For translators: From template Tiles/template-mail-message.html */
		Catalog.GetString ("Email subject:");
		/* For translators: From template Tiles/template-mail-message.html */
		Catalog.GetString ("Folder:");
		/* For translators: From template Tiles/template-mail-message.html */
		Catalog.GetString ("Open");
		/* For translators: From template Tiles/template-mail-message.html */
		Catalog.GetString ("Send IM");
		/* For translators: From template Tiles/template-music.html */
		Catalog.GetString ("Track");
		/* For translators: From template Tiles/template-music.html */
		Catalog.GetString ("from");
		/* For translators: From template Tiles/template-music.html */
		Catalog.GetString ("Open");
		/* For translators: From template Tiles/template-music.html */
		Catalog.GetString ("Enqueue");
		/* For translators: From template Tiles/template-music.html */
		Catalog.GetString ("Reveal in file manager");
		/* For translators: From template Tiles/template-note.html */
		Catalog.GetString ("last modified");
		/* For translators: From template Tiles/template-note.html */
		Catalog.GetString ("Open");
		/* For translators: From template Tiles/template-picture.html */
		Catalog.GetString ("in folder");
		/* For translators: From template Tiles/template-picture.html */
		Catalog.GetString ("Modified:");
		/* For translators: From template Tiles/template-picture.html */
		Catalog.GetString ("Tags:");
		/* For translators: From template Tiles/template-picture.html */
		Catalog.GetString ("Description:");
		/* For translators: From template Tiles/template-picture.html */
		Catalog.GetString ("Open");
		/* For translators: From template Tiles/template-picture.html */
		Catalog.GetString ("Send to...");
		/* For translators: From template Tiles/template-picture.html */
		Catalog.GetString ("Reveal in file manager");
		/* For translators: From template Tiles/template-presentation.html */
		Catalog.GetString ("in folder");
		/* For translators: From template Tiles/template-presentation.html */
		Catalog.GetString ("Last modified");
		/* For translators: From template Tiles/template-presentation.html */
		Catalog.GetString ("Title:");
		/* For translators: From template Tiles/template-presentation.html */
		Catalog.GetString ("Author:");
		/* For translators: From template Tiles/template-presentation.html */
		Catalog.GetString ("Slides:");
		/* For translators: From template Tiles/template-presentation.html */
		Catalog.GetString ("Open");
		/* For translators: From template Tiles/template-presentation.html */
		Catalog.GetString ("Send to...");
		/* For translators: From template Tiles/template-presentation.html */
		Catalog.GetString ("Reveal in file manager");
		/* For translators: From template Tiles/template-spreadsheet.html */
		Catalog.GetString ("in folder");
		/* For translators: From template Tiles/template-spreadsheet.html */
		Catalog.GetString ("Last modified");
		/* For translators: From template Tiles/template-spreadsheet.html */
		Catalog.GetString ("Title:");
		/* For translators: From template Tiles/template-spreadsheet.html */
		Catalog.GetString ("Author:");
		/* For translators: From template Tiles/template-spreadsheet.html */
		Catalog.GetString ("Open");
		/* For translators: From template Tiles/template-spreadsheet.html */
		Catalog.GetString ("Send to...");
		/* For translators: From template Tiles/template-spreadsheet.html */
		Catalog.GetString ("Reveal in file manager");
		/* For translators: From template Tiles/template-web-history.html */
		Catalog.GetString ("Last viewed:");
		/* For translators: From template Tiles/template-web-history.html */
		Catalog.GetString ("Open");
		/* For translators: From template Tiles/template-network.html */
		Catalog.GetString ("from Networked Beagle on host");
		/* For translators: From template Tiles/template-network.html */
		Catalog.GetString ("Open");
		/* For translators: From template Tiles/template-network.html */
		Catalog.GetString ("Search Networked Beagle");
		/* For translators: From template Tiles/template-im-log.html */
		Catalog.GetString ("Open");
	}
}
